Index: /issm/trunk-jpl/src/m/classes/pairoptions.py
===================================================================
--- /issm/trunk-jpl/src/m/classes/pairoptions.py	(revision 14100)
+++ /issm/trunk-jpl/src/m/classes/pairoptions.py	(revision 14101)
@@ -78,5 +78,5 @@
 #	%DELETEDUPLICATES - delete duplicates in an option list
 #
-#		%track the first occurance of each option
+#		%track the first occurrence of each option
 #		[dummy lines]=unique(obj.list(:,1),'first');
 #		clear dummy
@@ -87,5 +87,5 @@
 #			for i=1:numoptions,
 #				if ~ismember(i,lines),
-#					disp(['WARNING: option ' obj.list{i,1} ' appeared more than once. Only its first occurence will be kept'])
+#					disp(['WARNING: option ' obj.list{i,1} ' appeared more than once. Only its first occurrence will be kept'])
 #				end
 #			end
@@ -128,14 +128,14 @@
 	# }}}
 
-	#def fieldoccurences(self,field): #{{{
+	#def fieldoccurrences(self,field): #{{{
 	#	'''
-	#	FIELDOCCURENCES - get number of occurence of a field
+	#	FIELDOCCURRENCES - get number of occurrence of a field
 	#	'''
 	#
 	#	#check input 
 	#	if not isinstance(field,(str,unicode)):
-	#		raise TypeError("fieldoccurences error message: field should be a string")
-
-	#	#get number of occurence
+	#		raise TypeError("fieldoccurrences error message: field should be a string")
+
+	#	#get number of occurrence
 	#	# ??
 	#	#return num
Index: /issm/trunk-jpl/src/m/classes/plotoptions.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/plotoptions.m	(revision 14100)
+++ /issm/trunk-jpl/src/m/classes/plotoptions.m	(revision 14101)
@@ -68,5 +68,5 @@
 
 			 %get number of data to be plotted
-			 numberofplots=fieldoccurences(rawoptions,'data');
+			 numberofplots=fieldoccurrences(rawoptions,'data');
 			 opt.numberofplots=numberofplots;
 
Index: /issm/trunk-jpl/src/m/classes/settings.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/settings.m	(revision 14100)
+++ /issm/trunk-jpl/src/m/classes/settings.m	(revision 14101)
@@ -38,5 +38,5 @@
 			%onto the model after a parallel run by waiting for the lock file
 			%N minutes that is generated once the solution has converged
-			%0 to desactivate
+			%0 to deactivate
 			obj.waitonlock=Inf;
 		end % }}}
Index: /issm/trunk-jpl/src/m/classes/settings.py
===================================================================
--- /issm/trunk-jpl/src/m/classes/settings.py	(revision 14100)
+++ /issm/trunk-jpl/src/m/classes/settings.py	(revision 14101)
@@ -56,6 +56,6 @@
 		#onto the model after a parallel run by waiting for the lock file
 		#N minutes that is generated once the solution has converged
-		#0 to desactivate
-		self.waitonlock=float('Inf')
+		#0 to deactivate
+		self.waitonlock=2**31-1
 
 		return self

Index: /issm/trunk-jpl/src/m/classes/pairoptions.m
===================================================================
--- /issm/trunk-jpl/src/m/classes/pairoptions.m	(revision 14100)
+++ /issm/trunk-jpl/src/m/classes/pairoptions.m	(revision 14101)
@@ -84,5 +84,5 @@
 		%CHANGEOPTIONVALUE - change the value of an option in an option list
 
 			%track occurance of field
 			lines=find(strcmpi(obj.list(:,1),field));
 
@@ -100,5 +100,5 @@
 		%DELETEDUPLICATES - delete duplicates in an option list
 
 			%track the first occurance of each option
 			[dummy lines]=unique(obj.list(:,1),'first');
 			clear dummy
@@ -109,5 +109,5 @@
 				for i=1:numoptions,
 					if ~ismember(i,lines),
-						disp(['WARNING: option ' obj.list{i,1} ' appeared more than once. Only its first occurence will be kept'])
+						disp(['WARNING: option ' obj.list{i,1} ' appeared more than once. Only its first occurrence will be kept'])
 					end
 				end
@@ -137,5 +137,5 @@
 		end % }}}
 		function bool = exist(obj,field) % {{{
-		%EXIST - check if the option exist
+		%EXIST - check if the option exists
 
 			%some argument checking: 
@@ -150,13 +150,13 @@
 			bool=any(strcmpi(field,obj.list(:,1)));
 		end % }}}
-		function num = fieldoccurences(obj,field), % {{{
-		%FIELDOCCURENCES - get number of occurence of a field
+		function num = fieldoccurrences(obj,field), % {{{
+		%FIELDOCCURRENCES - get number of occurrence of a field
 
 			%check input 
 			if ~ischar(field),
-				error('fieldoccurences error message: field should be a string');
-			end
-
-			%get number of occurence
+				error('fieldoccurrences error message: field should be a string');
+			end
+
+			%get number of occurrence
 			num=sum(strcmpi(field,obj.list(:,1)));
 		end % }}}
@@ -204,5 +204,5 @@
 		%      obj=removefield(obj,field,warn)
 		%
-		%   if warn==1 display an info message to wan user that
+		%   if warn==1 display an info message to warn user that
 		%   some of his options have been removed.
 
@@ -84,5 +84,5 @@
 		%CHANGEOPTIONVALUE - change the value of an option in an option list
 
-			%track occurance of field
+			%track occurrence of field
 			lines=find(strcmpi(obj.list(:,1),field));
 
@@ -100,5 +100,5 @@
 		%DELETEDUPLICATES - delete duplicates in an option list
 
-			%track the first occurance of each option
+			%track the first occurrence of each option
 			[dummy lines]=unique(obj.list(:,1),'first');
 			clear dummy